summaryrefslogtreecommitdiffstats
path: root/chrome/plugin
diff options
context:
space:
mode:
authorpinkerton@chromium.org <pinkerton@chromium.org@0039d316-1c4b-4281-b951-d872f2087c98>2010-03-12 16:45:33 +0000
committerpinkerton@chromium.org <pinkerton@chromium.org@0039d316-1c4b-4281-b951-d872f2087c98>2010-03-12 16:45:33 +0000
commit44ce0b1adb867c77d02c45c2eb2a6c7ee3471167 (patch)
tree44e85d5ce38d7c5f15381c0bce2ba42dbd2715e9 /chrome/plugin
parentc1aeaac2015e93e1168453d4de29619c43fda669 (diff)
downloadchromium_src-44ce0b1adb867c77d02c45c2eb2a6c7ee3471167.zip
chromium_src-44ce0b1adb867c77d02c45c2eb2a6c7ee3471167.tar.gz
chromium_src-44ce0b1adb867c77d02c45c2eb2a6c7ee3471167.tar.bz2
Rename uses of GPUPlugin in class names and IPC to AcceleratedSurface.
BUG=none TEST=Purely cleanup, no functional changes. Review URL: http://codereview.chromium.org/855003 git-svn-id: svn://svn.chromium.org/chrome/trunk/src@41435 0039d316-1c4b-4281-b951-d872f2087c98
Diffstat (limited to 'chrome/plugin')
-rw-r--r--chrome/plugin/command_buffer_stub.cc26
-rw-r--r--chrome/plugin/webplugin_delegate_stub.cc6
-rw-r--r--chrome/plugin/webplugin_delegate_stub.h6
-rw-r--r--chrome/plugin/webplugin_proxy.cc7
4 files changed, 23 insertions, 22 deletions
diff --git a/chrome/plugin/command_buffer_stub.cc b/chrome/plugin/command_buffer_stub.cc
index 5ae203d..577bcfc 100644
--- a/chrome/plugin/command_buffer_stub.cc
+++ b/chrome/plugin/command_buffer_stub.cc
@@ -192,29 +192,31 @@ void CommandBufferStub::OnSetWindowSize(int32 width, int32 height) {
uint64 new_backing_store = processor_->SetWindowSizeForIOSurface(width,
height);
if (new_backing_store) {
- Send(new PluginHostMsg_GPUPluginSetIOSurface(plugin_host_route_id_,
- window_,
- width,
- height,
- new_backing_store));
+ Send(new PluginHostMsg_AcceleratedSurfaceSetIOSurface(
+ plugin_host_route_id_,
+ window_,
+ width,
+ height,
+ new_backing_store));
} else {
// If |new_backing_store| is 0, it might mean that the IOSurface APIs are
// not available. In this case, see if TransportDIBs are supported.
TransportDIB::Handle transport_dib =
processor_->SetWindowSizeForTransportDIB(width, height);
if (TransportDIB::is_valid(transport_dib)) {
- Send(new PluginHostMsg_GPUPluginSetTransportDIB(plugin_host_route_id_,
- window_,
- width,
- height,
- transport_dib));
+ Send(new PluginHostMsg_AcceleratedSurfaceSetTransportDIB(
+ plugin_host_route_id_,
+ window_,
+ width,
+ height,
+ transport_dib));
}
}
}
void CommandBufferStub::SwapBuffersCallback() {
- Send(new PluginHostMsg_GPUPluginBuffersSwapped(plugin_host_route_id_,
- window_));
+ Send(new PluginHostMsg_AcceleratedSurfaceBuffersSwapped(plugin_host_route_id_,
+ window_));
}
void CommandBufferStub::AllocTransportDIB(const size_t size,
diff --git a/chrome/plugin/webplugin_delegate_stub.cc b/chrome/plugin/webplugin_delegate_stub.cc
index e3d477e..dd3f6a0 100644
--- a/chrome/plugin/webplugin_delegate_stub.cc
+++ b/chrome/plugin/webplugin_delegate_stub.cc
@@ -143,8 +143,8 @@ void WebPluginDelegateStub::OnMessageReceived(const IPC::Message& msg) {
IPC_MESSAGE_HANDLER(PluginMsg_DestroyCommandBuffer,
OnDestroyCommandBuffer)
#if defined(OS_MACOSX)
- IPC_MESSAGE_HANDLER(PluginMsg_SetFakeGPUPluginWindowHandle,
- OnSetFakeGPUPluginWindowHandle)
+ IPC_MESSAGE_HANDLER(PluginMsg_SetFakeAcceleratedSurfaceWindowHandle,
+ OnSetFakeAcceleratedSurfaceWindowHandle)
#endif
IPC_MESSAGE_UNHANDLED_ERROR()
IPC_END_MESSAGE_MAP()
@@ -460,7 +460,7 @@ void WebPluginDelegateStub::OnHTTPRangeRequestReply(
}
#if defined(OS_MACOSX)
-void WebPluginDelegateStub::OnSetFakeGPUPluginWindowHandle(
+void WebPluginDelegateStub::OnSetFakeAcceleratedSurfaceWindowHandle(
gfx::PluginWindowHandle window) {
delegate_->set_windowed_handle(window);
}
diff --git a/chrome/plugin/webplugin_proxy.cc b/chrome/plugin/webplugin_proxy.cc
index e7826fd..54eb549 100644
--- a/chrome/plugin/webplugin_proxy.cc
+++ b/chrome/plugin/webplugin_proxy.cc
@@ -584,7 +584,7 @@ void WebPluginProxy::BindFakePluginWindowHandle() {
void WebPluginProxy::AcceleratedFrameBuffersDidSwap(
gfx::PluginWindowHandle window) {
// TODO(pinkerton): Rename this message.
- Send(new PluginHostMsg_GPUPluginBuffersSwapped(route_id_, window));
+ Send(new PluginHostMsg_AcceleratedSurfaceBuffersSwapped(route_id_, window));
}
void WebPluginProxy::SetAcceleratedSurface(gfx::PluginWindowHandle window,
@@ -592,9 +592,8 @@ void WebPluginProxy::SetAcceleratedSurface(gfx::PluginWindowHandle window,
int32 height,
uint64 accelerated_surface_identifier) {
// TODO(pinkerton): Rename this message.
- Send(new PluginHostMsg_GPUPluginSetIOSurface(route_id_, window, width,
- height,
- accelerated_surface_identifier));
+ Send(new PluginHostMsg_AcceleratedSurfaceSetIOSurface(
+ route_id_, window, width, height, accelerated_surface_identifier));
}
#endif
diff --git a/chrome/plugin/webplugin_delegate_stub.h b/chrome/plugin/webplugin_delegate_stub.h
index 64dea79d..ecc4b8f 100644
--- a/chrome/plugin/webplugin_delegate_stub.h
+++ b/chrome/plugin/webplugin_delegate_stub.h
@@ -122,10 +122,10 @@ class WebPluginDelegateStub : public IPC::Channel::Listener,
scoped_ptr<CommandBufferStub> command_buffer_stub_;
#if defined(OS_MACOSX)
// If this is the GPU plugin, we need to be receive a fake window
// handle which is used for subsequent communication back to the
// browser.
- void OnSetFakeGPUPluginWindowHandle(gfx::PluginWindowHandle window);
+ void OnSetFakeAcceleratedSurfaceWindowHandle(gfx::PluginWindowHandle window);
#endif
#endif
@@ -122,10 +122,10 @@ class WebPluginDelegateStub : public IPC::Channel::Listener,
scoped_ptr<CommandBufferStub> command_buffer_stub_;
#if defined(OS_MACOSX)
- // If this is the GPU plugin, we need to be receive a fake window
- // handle which is used for subsequent communication back to the
+ // If this is a GPU-accelerated plug-in, we need to be able to receive a fake
+ // window handle which is used for subsequent communication back to the
// browser.